@@ -1,5 +1,5 @@
 package Specio::Constraint::Role::CanType;
-$Specio::Constraint::Role::CanType::VERSION = '0.10';
+$Specio::Constraint::Role::CanType::VERSION = '0.11';
 use strict;
 use warnings;
 
@@ -17,7 +17,8 @@ with 'Specio::Constraint::Role::Interface';
 
     for my $name (qw( parent _inline_generator )) {
         $attrs->{$name}{init_arg} = undef;
-        $attrs->{$name}{builder} = '_build_' . ( $name =~ s/^_//r );
+        $attrs->{$name}{builder}
+            = $name =~ /^_/ ? '_build' . $name : '_build_' . $name;
     }
 
     $attrs->{methods} = {
@@ -75,7 +76,7 @@ Specio::Constraint::Role::CanType - Provides a common implementation for Specio:
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 DESCRIPTION
 
